@@ -1427,16 +1427,17 @@ get_pools(int *nrows)
 
 	int			lines = 0;
 
-	POOL_REPORT_POOLS *pools = palloc(
-									  pool_config->num_init_children * pool_config->max_pool * NUM_BACKENDS * sizeof(POOL_REPORT_POOLS)
+	POOL_REPORT_POOLS *pools = palloc0(
+		pool_config->num_init_children * pool_config->max_pool * NUM_BACKENDS * sizeof(POOL_REPORT_POOLS)
 	);
 
 	for (child = 0; child < pool_config->num_init_children; child++)
 	{
-		proc_id = process_info[child].pid;
-		pi = pool_get_process_info(proc_id);
-
 		int exist_live_connection = 0;
+
+		pi = &process_info[child];
+		proc_id = pi->pid;
+
 		for (pool = 0; pool < pool_config->max_pool; pool++)
 		{
 			poolBE = pool * MAX_NUM_BACKENDS;
@@ -1452,6 +1453,7 @@ get_pools(int *nrows)
 		{
 			int idle_duration = pi->connection_info[pool * MAX_NUM_BACKENDS].client_idle_duration;
 			int cliet_idle_time = pool_config->client_idle_limit;
+
 			if (pool_config->client_idle_limit > 0)
 			{
 				cliet_idle_time = pool_config->client_idle_limit - idle_duration;
@@ -1605,6 +1607,9 @@ pools_reporting(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend)
 	pfree(pools);
 }
 
+/*
+ * Used by SHOW pool_processes
+ */
 POOL_REPORT_PROCESSES *
 get_processes(int *nrows)
 {
@@ -1614,14 +1619,15 @@ get_processes(int *nrows)
 	ProcessInfo *pi = NULL;
 	int			proc_id;
 
-	POOL_REPORT_PROCESSES *processes = palloc(pool_config->num_init_children * sizeof(POOL_REPORT_PROCESSES));
+	POOL_REPORT_PROCESSES *processes = palloc0(pool_config->num_init_children * sizeof(POOL_REPORT_PROCESSES));
 
 	for (child = 0; child < pool_config->num_init_children; child++)
 	{
-		proc_id = process_info[child].pid;
-		pi = pool_get_process_info(proc_id);
-
 		int exist_live_connection = 0;
+
+		pi = &process_info[child];
+		proc_id = pi->pid;
+
 		for (pool = 0; pool < pool_config->max_pool; pool++)
 		{
 			poolBE = pool * MAX_NUM_BACKENDS;
@@ -1662,7 +1668,9 @@ get_processes(int *nrows)
 		for (pool = 0; pool < pool_config->max_pool; pool++)
 		{
 			poolBE = pool * MAX_NUM_BACKENDS;
-			if (pi->connection_info[poolBE].connected && strlen(pi->connection_info[poolBE].database) > 0 && strlen(pi->connection_info[poolBE].user) > 0)
+			if (pi->connection_info[poolBE].connected &&
+				strlen(pi->connection_info[poolBE].database) > 0 &&
+				strlen(pi->connection_info[poolBE].user) > 0)
 			{
 				StrNCpy(processes[child].database, pi->connection_info[poolBE].database, POOLCONFIG_MAXIDENTLEN);
 				StrNCpy(processes[child].username, pi->connection_info[poolBE].user, POOLCONFIG_MAXIDENTLEN);
